@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011, 2012, 2013
+ * Copyright (C) 2010, 2011, 2012, 2013, 2015
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -121,7 +121,7 @@ extern "C" int gtatool_to_netpbm(int argc, char *argv[])
             struct pam outpam;
             std::memset(&outpam, 0, sizeof(outpam));
             outpam.size = sizeof(struct pam);
-#ifdef PAM_STRUCT_SIZE
+#if 0
             outpam.len = PAM_STRUCT_SIZE(tuple_type);
 #else
             outpam.len = outpam.size;
