@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# Copyright (C) 2011
+# Copyright (C) 2011, 2013
 # Martin Lambers <marlam@marlam.de>
 #
 # Copying and distribution of this file, with or without modification, are
@@ -23,4 +23,12 @@ cmp "$TMPD"/a.gta "$TMPD"/xa.gta
 cmp "$TMPD"/b.gta "$TMPD"/xb.gta
 cmp "$TMPD"/c.gta "$TMPD"/xc.gta
 
+$GTA create -d 10 -n5 > "$TMPD"/empty0.gta
+$GTA create -c uint8,uint16 -n5 > "$TMPD"/empty1.gta
+$GTA create -c uint16,uint8 -n5 > "$TMPD"/empty2.gta
+$GTA component-reorder "$TMPD"/empty0.gta > "$TMPD"/xempty0.gta
+cmp "$TMPD"/empty0.gta "$TMPD"/xempty0.gta
+$GTA component-reorder -i 1,0 "$TMPD"/empty1.gta > "$TMPD"/xempty2.gta
+cmp "$TMPD"/empty2.gta "$TMPD"/xempty2.gta
+
 rm -r "$TMPD"
